Human Protein Atlas Tissue Data (transposed and subsampled)
Source:R/example_adata.R
example_adata.RdHuman Protein Atlas tissue bulk-RNA expression data in AnnDatR format transposed and subsampled (981 selected genes).
Format
An AnnDatR object with the following structure:
- X
A data frame with 78 rows and 982 columns representing the main data matrix (e.g., gene expression values).
- obs
A data frame with 981 rows and 11 columns containing metadata for observations (e.g., genes).
- obs_names_col
A string specifying the column used for observation names (
ensembl_id).- var
A data frame with 78 rows and 7 columns containing metadata for variables (e.g., samples).
- var_names_col
A string specifying the column used for variable names (
sample_id).- uns
A list for storing unstructured metadata (currently
NULL).- obsm
A list for storing multidimensional annotations for observations (currently
NULL).- raw
A slot for storing raw data (currently
NULL).